@@ -1,6 +1,7 @@
 using Test
 using LinearAlgebra, Adapt
 using FixedSizeArrays
+using FixedSizeArrays: checked_dims
 using Collects: collect_as
 using OffsetArrays: OffsetArray
 using Random: Random
@@ -19,8 +20,6 @@ const build_is_production_build = let v = get(ENV, build_is_production_build_env
     end
 end::Bool
 
-const checked_dims = FixedSizeArrays.checked_dims
-
 # helpers for testing for allocation or suboptimal inference
 
 allocated(f::F,      args::Tuple) where {F} = @allocated f(args...)
@@ -103,9 +102,10 @@ end
 
     @testset "safe computation of length from dimensions size" begin
         @test isone(checked_dims(()))
+        max_size = Sys.WORD_SIZE == 32 ? 12 : 20
         for n ∈ 0:30
             t = Tuple(1:n)
-            if 20 < n
+            if n > max_size
                 @test_throws ArgumentError checked_dims(t)
             else
                 @test factorial(n) == prod(t) == checked_dims(t)
@@ -299,6 +299,25 @@ end
             end
         end
 
+        @testset "destructuring" begin
+            vec = FSV(rand(3))
+            mat = FSM(rand(3, 3))
+            @testset "`Base.rest`" begin
+                @test let (v...,) = vec
+                    v isa AbstractVector
+                end
+                @test let (v...,) = mat
+                    v isa AbstractVector
+                end
+                @test let (v...,) = vec
+                    v == vec
+                end
+                @test let (v...,) = mat
+                    v == reshape(mat, :)
+                end
+            end
+        end
+
         @testset "FixedSizeVector" begin
             v = FSV{Float64}(undef, 3)
             @test length(v) == 3
@@ -455,7 +474,7 @@ end
             m = FixedSizeArray(rand(2, 2))::FixedSizeArray
             @test m == copy(m)
             @test m !== copy(m)
-            @test m == m[:]
+            @test reshape(m, :) == m[:]
             @test m !== m[:]
         end
 
@@ -541,7 +560,8 @@ end
                             @test prod(shape1) === prod(shape2) === len  # meta
                             T = FSA{elem_type,length(shape2)}
                             test_inferred_noalloc(reshape, T, (a, shape2))
-                            test_inferred_noalloc(reshape, T, (a, shape2...))
+                            test_inferred(reshape, T, (a, shape2...))
+                            test_inferred_noalloc(((a, s) -> reshape(a, s...)), T, (a, shape2))
                             b = reshape(a, shape2)
                             @test size(b) === shape2
                             @test parent(a) === parent(b)
@@ -678,4 +698,23 @@ end
         @test farr isa Transpose
         @test parent(farr) isa FixedSizeArray
     end
+
+    @testset "Constant-prop through iterate" begin
+        @test Base.return_types() do
+            m = FixedSizeArray{Int}(undef, 3)
+            m[1] = 1
+            m[2] = 2
+            m[3] = 3
+            tuple(m...)
+       end[] == NTuple{3, Int}
+    end
+
+    @testset "getindex with a single colon must return an `AbstractVector`" begin
+        for m in 0:3
+            @test let a = FixedSizeArray{Float32}(undef, ntuple(Returns(1), m))
+                a::AbstractArray{<:Any, m}
+                a[:] isa AbstractVector
+            end
+        end
+    end
 end
